/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/cen-lnx64-xr/build/dom/indexedDB/nsIIDBErrorEvent.idl
 */

#ifndef __gen_nsIIDBErrorEvent_h__
#define __gen_nsIIDBErrorEvent_h__


#ifndef __gen_nsIIDBEvent_h__
#include "nsIIDBEvent.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIIDBErrorEvent */
#define NS_IIDBERROREVENT_IID_STR "b2048056-3ed9-4975-97cc-dea74282b607"

#define NS_IIDBERROREVENT_IID \
  {0xb2048056, 0x3ed9, 0x4975, \
    { 0x97, 0xcc, 0xde, 0xa7, 0x42, 0x82, 0xb6, 0x07 }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIIDBErrorEvent : public nsIIDBEvent {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIDBERROREVENT_IID)

  /**
   * See nsIIDBDatabaseException.idl
   */
  /* readonly attribute unsigned short code; */
  NS_SCRIPTABLE NS_IMETHOD GetCode(PRUint16 *aCode) = 0;

  /* readonly attribute DOMString message; */
  NS_SCRIPTABLE NS_IMETHOD GetMessage(nsAString & aMessage) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIIDBErrorEvent, NS_IIDBERROREVENT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIDBERROREVENT \
  NS_SCRIPTABLE NS_IMETHOD GetCode(PRUint16 *aCode); \
  NS_SCRIPTABLE NS_IMETHOD GetMessage(nsAString & aMessage); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIDBERROREVENT(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetCode(PRUint16 *aCode) { return _to GetCode(aCode); } \
  NS_SCRIPTABLE NS_IMETHOD GetMessage(nsAString & aMessage) { return _to GetMessage(aMessage); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIDBERROREVENT(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetCode(PRUint16 *aCode) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCode(aCode); } \
  NS_SCRIPTABLE NS_IMETHOD GetMessage(nsAString & aMessage) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessage(aMessage); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsIDBErrorEvent : public nsIIDBErrorEvent
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIDBERROREVENT

  nsIDBErrorEvent();

private:
  ~nsIDBErrorEvent();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsIDBErrorEvent, nsIIDBErrorEvent)

nsIDBErrorEvent::nsIDBErrorEvent()
{
  /* member initializers and constructor code */
}

nsIDBErrorEvent::~nsIDBErrorEvent()
{
  /* destructor code */
}

/* readonly attribute unsigned short code; */
NS_IMETHODIMP nsIDBErrorEvent::GetCode(PRUint16 *aCode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute DOMString message; */
NS_IMETHODIMP nsIDBErrorEvent::GetMessage(nsAString & aMessage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIIDBErrorEvent_h__ */
