/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/cen-lnx64-xr/build/dom/interfaces/svg/nsIDOMSVGTitleElement.idl
 */

#ifndef __gen_nsIDOMSVGTitleElement_h__
#define __gen_nsIDOMSVGTitleElement_h__


#ifndef __gen_nsIDOMSVGElement_h__
#include "nsIDOMSVGElement.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMSVGTitleElement */
#define NS_IDOMSVGTITLEELEMENT_IID_STR "524564b0-13a3-459b-bbec-ad66aea9f789"

#define NS_IDOMSVGTITLEELEMENT_IID \
  {0x524564b0, 0x13a3, 0x459b, \
    { 0xbb, 0xec, 0xad, 0x66, 0xae, 0xa9, 0xf7, 0x89 }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIDOMSVGTitleElement : public nsIDOMSVGElement {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDOMSVGTITLEELEMENT_IID)

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDOMSVGTitleElement, NS_IDOMSVGTITLEELEMENT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMSVGTITLEELEMENT \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMSVGTITLEELEMENT(_to) \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMSVGTITLEELEMENT(_to) \
  /* no methods! */

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMSVGTitleElement : public nsIDOMSVGTitleElement
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMSVGTITLEELEMENT

  nsDOMSVGTitleElement();

private:
  ~nsDOMSVGTitleElement();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMSVGTitleElement, nsIDOMSVGTitleElement)

nsDOMSVGTitleElement::nsDOMSVGTitleElement()
{
  /* member initializers and constructor code */
}

nsDOMSVGTitleElement::~nsDOMSVGTitleElement()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMSVGTitleElement_h__ */
