/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/cen-lnx64-xr/build/dom/indexedDB/nsIIDBSuccessEvent.idl
 */

#ifndef __gen_nsIIDBSuccessEvent_h__
#define __gen_nsIIDBSuccessEvent_h__


#ifndef __gen_nsIIDBEvent_h__
#include "nsIIDBEvent.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
#include "jsapi.h"

/* starting interface:    nsIIDBSuccessEvent */
#define NS_IIDBSUCCESSEVENT_IID_STR "9275d34f-54e1-4ab0-b4ca-f8d4359eec9c"

#define NS_IIDBSUCCESSEVENT_IID \
  {0x9275d34f, 0x54e1, 0x4ab0, \
    { 0xb4, 0xca, 0xf8, 0xd4, 0x35, 0x9e, 0xec, 0x9c }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIIDBSuccessEvent : public nsIIDBEvent {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIDBSUCCESSEVENT_IID)

  /* [implicit_jscontext] readonly attribute jsval result; */
  NS_SCRIPTABLE NS_IMETHOD GetResult(JSContext *cx, jsval *aResult) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIIDBSuccessEvent, NS_IIDBSUCCESSEVENT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIDBSUCCESSEVENT \
  NS_SCRIPTABLE NS_IMETHOD GetResult(JSContext *cx, jsval *aResult); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIDBSUCCESSEVENT(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetResult(JSContext *cx, jsval *aResult) { return _to GetResult(cx, aResult); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIDBSUCCESSEVENT(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetResult(JSContext *cx, jsval *aResult) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetResult(cx, aResult); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsIDBSuccessEvent : public nsIIDBSuccessEvent
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIDBSUCCESSEVENT

  nsIDBSuccessEvent();

private:
  ~nsIDBSuccessEvent();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsIDBSuccessEvent, nsIIDBSuccessEvent)

nsIDBSuccessEvent::nsIDBSuccessEvent()
{
  /* member initializers and constructor code */
}

nsIDBSuccessEvent::~nsIDBSuccessEvent()
{
  /* destructor code */
}

/* [implicit_jscontext] readonly attribute jsval result; */
NS_IMETHODIMP nsIDBSuccessEvent::GetResult(JSContext *cx, jsval *aResult)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIIDBSuccessEvent_h__ */
